obographs-dev
Crate with definitions of Obographs types and I/O functions.
Typically, the library should be used with serde feature enabled
to support parsing Obographs JSON files.
Therefore, the following should be added into Cargo.toml file:
obographs-dev = {version = '0.2.1', features = ["serde"]}Note: Check
crates.iofor the latest version and update0.2.1accordingly.
Examples
Create an Obographs type
The Obographs elements can be created programatically.
For instance, the [obographs::model::Edge] can be created as:
use obographs_dev::model::*;
let edge = Edge {
sub: String::from("http://purl.obolibrary.org/obo/HP_0001250"),
pred: String::from("is_a"),
obj: String::from("http://purl.obolibrary.org/obo/HP_0012638"),
meta: None,
};Read an Obographs JSON file
With serde feature enabled, we can read a JSON file
into a [obographs::model::GraphDocument] by running:
use obographs_dev::model::GraphDocument;
let toy_hpo_json = "tests/test_data/hp.mini.json";
let graph_document = GraphDocument::from_path(toy_hpo_json).expect("Read graph document from file path");
assert_eq!(graph_document.graphs.len(), 1);Tests and benches
Run tests with:
cargo test --features serdeThe benchmarks can be run with:
cargo bench --features serdeDisclaimer
The implementation of the Obographs model is INCOMPLETE. Attributes and components may be missing.
Modules
- model
- The module with Obographs types.